@@ -1,4 +1,3 @@
-import pandas as pd
 import re
 import datetime 
 
@@ -16,7 +15,7 @@ def find_year(df, use_delta=False):
     res = {}
     for colname in df:
         colregex = re.findall('\d\d\d\d', str(colname))
-        if len(colregex) == 1:
+        if len(colregex) >= 1:
             colyear = int(colregex[0])
 
         res[colname] = colyear
