@@ -4,6 +4,7 @@ Utility for forward contracts
 import re
 import pandas as pd
 from commodutil import dates
+from commodutil import transforms
 
 futures_month_conv = {
         1: "F",
@@ -188,12 +189,11 @@ def cal_spreads(q):
     Given a dataframe of cal contract values (eg CAL 2015, CAL 2020)
     with columns headings as 'CAL 2015', 'CAL 2020'
     Return a dataframe of cal spreads (eg CAL 2015-2016)
-    Does Q1-Q2, Q2-Q3, Q3-Q4, Q4-Q1
     """
 
     calspr = []
     for col in q.columns:
-        colcal = col.split(' ')[0]
+        # colcal = col.split(' ')[0]
         colcalyr = col.split(' ')[1]
 
         curyear = int(colcalyr)
@@ -206,4 +206,18 @@ def cal_spreads(q):
             calspr.append(r)
 
     res = pd.concat(calspr, 1, sort=True)
-    return res
\ No newline at end of file
+    return res
+
+
+def curve_seasonal_zscore(hist, fwd):
+    """
+    Given some history for a timeseries and a forward curve, calculate the monthly
+    z-score (std dev away from mean) along the forward curve
+    """
+
+    d = transforms.monthly_mean(hist).T.describe()
+
+    if isinstance(fwd, pd.Series):
+        fwd = pd.DataFrame(fwd)
+    fwd['zscore'] = fwd.apply(lambda x: (d[x.name.month].loc['mean'] - x.iloc[0]) / d[x.name.month].loc['std'], 1)
+    return fwd
